exceptiontools.MarkError
========================

.. inheritance-diagram:: abjad.tools.exceptiontools.MarkError.MarkError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.MarkError.MarkError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.MarkError.MarkError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MarkError.MarkError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MarkError.MarkError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MarkError.MarkError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MarkError.MarkError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MarkError.MarkError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MarkError.MarkError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MarkError.MarkError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
